@@ -3,19 +3,19 @@
     Test suite for the util module
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2006-2014 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2017 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 import re
 import unittest
 
-from pygments import util
+from pygments import util, console
 
 
 class FakeLexer(object):
     def analyse(text):
-        return float(text)
+        return text
     analyse = util.make_analysator(analyse)
 
 
@@ -40,6 +40,10 @@ class UtilTest(unittest.TestCase):
         equals(util.get_list_opt({}, 'a', '1 2'), ['1', '2'])
         raises(util.OptionError, util.get_list_opt, {}, 'a', 1)
 
+        equals(util.get_choice_opt({}, 'a', ['foo', 'bar'], 'bar'), 'bar')
+        equals(util.get_choice_opt({}, 'a', ['foo', 'bar'], 'Bar', True), 'bar')
+        raises(util.OptionError, util.get_choice_opt, {}, 'a',
+               ['foo', 'bar'], 'baz')
 
     def test_docstring_headline(self):
         def f1():
@@ -55,9 +59,12 @@ class UtilTest(unittest.TestCase):
 
             other text
             """
+        def f3():
+            pass
 
-        self.assertEqual(util.docstring_headline(f1), "docstring headline")
-        self.assertEqual(util.docstring_headline(f2), "docstring headline")
+        self.assertEqual(util.docstring_headline(f1), 'docstring headline')
+        self.assertEqual(util.docstring_headline(f2), 'docstring headline')
+        self.assertEqual(util.docstring_headline(f3), '')
 
     def test_analysator_returns_float(self):
         # If an analysator wrapped by make_analysator returns a floating point
@@ -88,10 +95,10 @@ class UtilTest(unittest.TestCase):
     def test_analysator_type_error(self):
         # When converting the analysator's return value to a float a
         # TypeError may occur.  If that happens 0.0 is returned instead.
-        self.assertEqual(FakeLexer.analyse(None), 0.0)
+        self.assertEqual(FakeLexer.analyse('xxx'), 0.0)
 
     def test_shebang_matches(self):
-        self.assertTrue(util.shebang_matches('#!/usr/bin/env python', r'python(2\.\d)?'))
+        self.assertTrue(util.shebang_matches('#!/usr/bin/env python\n', r'python(2\.\d)?'))
         self.assertTrue(util.shebang_matches('#!/usr/bin/python2.4', r'python(2\.\d)?'))
         self.assertTrue(util.shebang_matches('#!/usr/bin/startsomethingwith python',
                                              r'python(2\.\d)?'))
@@ -106,7 +113,7 @@ class UtilTest(unittest.TestCase):
 
     def test_doctype_matches(self):
         self.assertTrue(util.doctype_matches(
-            '<!DOCTYPE html PUBLIC "a"> <html>', 'html.*'))
+            '<!DOCTYPE html> <html>', 'html.*'))
         self.assertFalse(util.doctype_matches(
             '<?xml ?> <DOCTYPE html PUBLIC "a"> <html>', 'html.*'))
         self.assertTrue(util.html_doctype_matches(
@@ -157,3 +164,50 @@ class UtilTest(unittest.TestCase):
         # keeps first
         x = util.duplicates_removed(('a', 'b', 'a'))
         self.assertEqual(['a', 'b'], x)
+
+    def test_guess_decode(self):
+        # UTF-8 should be decoded as UTF-8
+        s = util.guess_decode(u'\xff'.encode('utf-8'))
+        self.assertEqual(s, (u'\xff', 'utf-8'))
+
+        # otherwise, it could be latin1 or the locale encoding...
+        import locale
+        s = util.guess_decode(b'\xff')
+        self.assertTrue(s[1] in ('latin1', locale.getpreferredencoding()))
+
+    def test_guess_decode_from_terminal(self):
+        class Term:
+            encoding = 'utf-7'
+
+        s = util.guess_decode_from_terminal(u'\xff'.encode('utf-7'), Term)
+        self.assertEqual(s, (u'\xff', 'utf-7'))
+
+        s = util.guess_decode_from_terminal(u'\xff'.encode('utf-8'), Term)
+        self.assertEqual(s, (u'\xff', 'utf-8'))
+
+    def test_add_metaclass(self):
+        class Meta(type):
+            pass
+
+        @util.add_metaclass(Meta)
+        class Cls:
+            pass
+
+        self.assertEqual(type(Cls), Meta)
+
+
+class ConsoleTest(unittest.TestCase):
+
+    def test_ansiformat(self):
+        f = console.ansiformat
+        c = console.codes
+        all_attrs = f('+*_blue_*+', 'text')
+        self.assertTrue(c['blue'] in all_attrs and c['blink'] in all_attrs
+                        and c['bold'] in all_attrs and c['underline'] in all_attrs
+                        and c['reset'] in all_attrs)
+        self.assertRaises(KeyError, f, '*mauve*', 'text')
+
+    def test_functions(self):
+        self.assertEqual(console.reset_color(), console.codes['reset'])
+        self.assertEqual(console.colorize('blue', 'text'),
+                         console.codes['blue'] + 'text' + console.codes['reset'])
